# ctao-datamodel

Implementations of a subset of the CTAO data model as [pydantic](https://docs.pydantic.dev/latest/) schemas.

* [Documentation](http://cta-computing.gitlab-pages.cta-observatory.org/common/ctao-datamodel/latest/)
* [Repository](https://gitlab.cta-observatory.org/cta-computing/common/ctao-datamodel)

## Scope

The intention is to cover at least the metadata-aspects of the CTAO data model, i.e. the DataProducts model, and other models that will be serialized as JSON-like documents.  It does not cover the Science data models (DL3, etc), which are more complex.

## Purpose

This module can be used in other projects to help with validation of data against a machine-readable schema. The intention is to also auto-generate [JSONSchema](https://json-schema.org/) from the pydantic models in the CI, and export that as a separate package, to be used with projects that do not want to depend on pydantic, or python in general.
